/**********************************************************************
 *
 * Filename:    button.c
 * 
 * Description: Button device driver.
 *
 * Notes:       This file is specific to the Arcom board.
 * 
 * Copyright (c) 2006 Anthony Massa and Michael Barr. All rights reserved.
 * This code is from the book Programming Embedded Systems, With C and
 * GNU Development Tools, 2nd Edition.
 * It is provided AS-IS, WITHOUT ANY WARRANTY either expressed or implied.
 * You may study, use, and modify it for any non-commercial purpose,
 * including teaching and use in open-source projects.
 * You may distribute it non-commercially as long as you retain this notice.
 * For a commercial use license, or to purchase the book,
 * please visit http://www.oreilly.com/catalog/embsys2.
 *
 **********************************************************************/

#include "stdint.h"
#include "pxa270.h"
#include "lds4000.h"
#include "button.h"
#include <cyg/infra/diag.h>

#define SCAN1   (0x01)
#define SCAN2   (0x02)
#define SCAN3   (0x04)

void usleep(int usec){
	int i;

	for(i=0; i<usec;) i++;
}

/**********************************************************************
 *
 * Function:    buttonDebounce
 *
 * Description: This function gets the current state of the button.
 *
 * Notes:       This function is specific to the Arcom board. The
 *              default state on the button input signals is high.
 *              When a button is pressed, the input signal goes low.
 *
 * Returns:     The current state of the SW0 button.
 *
 **********************************************************************/ 
uint8_t buttonRead(void)
{
	uint8_t volatile *BUTTON_REG = (uint8_t volatile *)0x07000030;

	*BUTTON_REG = SCAN1;
	usleep(100);

	if ((*BUTTON_REG&0xff) == 0x01) return 1;
	if ((*BUTTON_REG&0xff) == 0x02) return 1;
	if ((*BUTTON_REG&0xff) == 0x04) return 1;
	if ((*BUTTON_REG&0xff) == 0x08) return 1;
	while ((*BUTTON_REG&0xff) != 0x00);

	*BUTTON_REG = SCAN2;
	usleep(100);

	if ((*BUTTON_REG&0xff) == 0x01) return 1;
	if ((*BUTTON_REG&0xff) == 0x02) return 1;
	if ((*BUTTON_REG&0xff) == 0x04) return 1;
	if ((*BUTTON_REG&0xff) == 0x08) return 1;
	while ((*BUTTON_REG&0xff) != 0x00);

	*BUTTON_REG = SCAN3;
	usleep(100);

	if ((*BUTTON_REG&0xff) == 0x01) return 1;
	if ((*BUTTON_REG&0xff) == 0x02) return 1;
	if ((*BUTTON_REG&0xff) == 0x04) return 1;
	if ((*BUTTON_REG&0xff) == 0x08) return 1;
	while ((*BUTTON_REG&0xff) != 0x00);

	return 0; 
}

/**********************************************************************
 *
 * Function:    buttonDebounce
 *
 * Description: This function debounces buttons.
 *
 * Notes:       
 *
 * Returns:     TRUE if the button edge is detected, otherwise
 *              FALSE is returned.
 *
 **********************************************************************/ 
int buttonDebounce(void)
{
    static uint16_t buttonState = 0;
    uint8_t pinState;    

    pinState = buttonRead();

    /* Store the current debounce status. */
    buttonState = ((buttonState << 1) | pinState | 0xE000);

    if (buttonState == 0xF000) return TRUE;
    return FALSE;
}
