/**********************************************************************
 *
 * Filename:    commands.c
 * 
 * Description: Command functions for command line interface.
 *
 * Notes:       
 *
 * 
 * Copyright (c) 2006 Anthony Massa and Michael Barr. All rights reserved.
 * This code is from the book Programming Embedded Systems, With C and
 * GNU Development Tools, 2nd Edition.
 * It is provided AS-IS, WITHOUT ANY WARRANTY either expressed or implied.
 * You may study, use, and modify it for any non-commercial purpose,
 * including teaching and use in open-source projects.
 * You may distribute it non-commercially as long as you retain this notice.
 * For a commercial use license, or to purchase the book,
 * please visit http://www.oreilly.com/catalog/embsys2.
 *
 **********************************************************************/

/**********************************************************************
 *
 * Notes:       This file is specific to the LDS4000 board
 * 
 * Copyright (c) 2007 Corebell System, Inc. All rights reserved.
 * You may study, use, and modify it for any non-commercial purpose,
 * including teaching and use in open-source projects.
 * You may distribute it non-commercially as long as you retain this notice.
 * For a commercial use license, or to purchase the book,
 * please visit http://corebell.co.kr
 *
 **********************************************************************/
 
#include "stdint.h"
#include "lds4000.h"
#include "led.h"
#include "sseg.h"
#include "serial.h"
#include "cli.h"
#include "commands.h"
#include "sseg.h"


/**********************************************************************
 *
 * Function:    commandsLed
 *
 * Description: Toggle the green LED command function.
 *
 * Notes:       
 *
 * Returns:     None.
 *
 **********************************************************************/
void commandsLed(void)
{
    ledToggle();
}


/**********************************************************************
 *
 * Function:    commandsSeg
 *
 * Description: Toggle the Seg command function.
 *
 * Notes:       
 *
 * Returns:     None.
 *
 **********************************************************************/
void commandsSeg(void)
{
	static int segToggle = 0;
	if( segToggle == 0 ) {
    	SSEGSet(0x0000, 0x0000, 0x0000, 0x0000);
    	segToggle = 1;
    }
    else {
    	SSEGSet(0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF);
    	segToggle = 0;
    }	
}


/**********************************************************************
 *
 * Function:    commandsHelp
 *
 * Description: Help command function.
 *
 * Notes:       
 *
 * Returns:     None.
 *
 **********************************************************************/
void commandsHelp(void)
{
    int idx;

    /* Loop through each command in the table and send out the command
     * name to the serial port. */
    for (idx = 0; gCommandTable[idx].name != NULL; idx++)
    {
        serialPutStr(gCommandTable[idx].name);
        serialPutStr("\r\n");
    }
}

